#!/bin/bash

set -e;

IPERF_MODE=$1
PORT=5678
ARG=""

function usage {
  echo ""; 
  echo "iperf.sh <server> ";
  echo "iperf.sh <client> <server-Ip> <test-duration>";
  exit 1;
}

function clean_up {
  if [ "$IPERF_MODE" == "server" ]
  then
    iptables -D INPUT -p tcp --dport $PORT -j ACCEPT
    exit;
  fi
}

trap clean_up SIGHUP SIGINT SIGTERM

if [ -z "$IPERF_MODE" ];
then
  echo ""; 
  echo "Missing first argument:  <server/client>";
  usage;
fi

if [ "$IPERF_MODE" == "server" ]
then
  echo "******************************************************"
  echo "                  IPerf Server Side                   "
  echo "******************************************************"

  ARG=" --server --one-off"
  iptables -I INPUT 1 -p tcp --dport $PORT -j ACCEPT

elif [ "$IPERF_MODE" == "client" ] 
then
  echo "******************************************************"
  echo "                  IPerf Client Side                   "
  echo "******************************************************"
  SERVER_IP=$2
  TIME_TO_RUN=$3

  if [ -z "$SERVER_IP" ];
  then
      echo "Please specify Server's IP";
      usage;
  fi

  if [ -z "$TIME_TO_RUN" ];
  then
      echo "Please specify Time (seconds) to run the test";
      usage
  fi

  ARG=" --client $SERVER_IP --parallel 2 --time $TIME_TO_RUN";
else
	echo "Wrong argument: $IPERF_MODE. Only <server/client> is valid" ;
        usage;
fi

ARG+=" --port $PORT --interval 1"
/bin/iperf3 $ARG

clean_up
